@@ -1142,29 +1142,28 @@ class InfoDto(RiotApiResponse):
 class ParticipantDto(RiotApiResponse):
     def __init__(self, assists: int, baronKills: int, bountyLevel: int, champExperience: int, champLevel: int,
                  championId: int, championName: str, championTransform: int, consumablesPurchased: int,
-                 damageDealtToBuildings: int, damageDealtToObjectives: int, damageDealtToTurrets: int,
-                 damageSelfMitigated: int, deaths: int, detectorWardsPlaced: int, doubleKills: int, dragonKills: int,
-                 firstBloodAssist: bool, firstBloodKill: bool, firstTowerAssist: bool, firstTowerKill: bool,
-                 gameEndedInEarlySurrender: bool, gameEndedInSurrender: bool, goldEarned: int, goldSpent: int,
-                 individualPosition: str, inhibitorKills: int, inhibitorsLost: int, item0: int,
-                 item1: int, item2: int, item3: int, item4: int, item5: int, item6: int, itemsPurchased: int,
-                 killingSprees: int, kills: int, lane: str, largestCriticalStrike: int, largestKillingSpree: int,
-                 largestMultiKill: int, longestTimeSpentLiving: int, magicDamageDealt: int,
+                 damageDealtToObjectives: int, damageDealtToTurrets: int, damageSelfMitigated: int, deaths: int,
+                 detectorWardsPlaced: int, doubleKills: int, dragonKills: int, firstBloodAssist: bool,
+                 firstBloodKill: bool, firstTowerAssist: bool, firstTowerKill: bool, gameEndedInEarlySurrender: bool,
+                 gameEndedInSurrender: bool, goldEarned: int, goldSpent: int, individualPosition: str,
+                 inhibitorKills: int, item0: int, item1: int, item2: int, item3: int, item4: int, item5: int,
+                 item6: int, itemsPurchased: int, killingSprees: int, kills: int, lane: str, largestCriticalStrike: int,
+                 largestKillingSpree: int, largestMultiKill: int, longestTimeSpentLiving: int, magicDamageDealt: int,
                  magicDamageDealtToChampions: int, magicDamageTaken: int, neutralMinionsKilled: int, nexusKills: int,
-                 nexusLost: int, objectivesStolen: int, objectivesStolenAssists: int,
-                 participantId: int, pentaKills: int, perks: dict, physicalDamageDealt: int,
-                 physicalDamageDealtToChampions: int, physicalDamageTaken: int, profileIcon: int, puuid: str,
-                 quadraKills: int, riotIdName: str, riotIdTagline: str, role: str, sightWardsBoughtInGame: int,
-                 spell1Casts: int, spell2Casts: int, spell3Casts: int, spell4Casts: int, summoner1Casts: int,
-                 summoner1Id: int, summoner2Casts: int, summoner2Id: int, summonerId: str, summonerLevel: int,
-                 summonerName: str, teamEarlySurrendered: bool, teamId: int, teamPosition: str, timeCCingOthers: int,
-                 timePlayed: int, totalDamageDealt: int, totalDamageDealtToChampions: int,
+                 objectivesStolen: int, objectivesStolenAssists: int, participantId: int, pentaKills: int, perks: dict,
+                 physicalDamageDealt: int, physicalDamageDealtToChampions: int, physicalDamageTaken: int,
+                 profileIcon: int, puuid: str, quadraKills: int, riotIdName: str, riotIdTagline: str, role: str,
+                 sightWardsBoughtInGame: int, spell1Casts: int, spell2Casts: int, spell3Casts: int, spell4Casts: int,
+                 summoner1Casts: int, summoner1Id: int, summoner2Casts: int, summoner2Id: int, summonerId: str,
+                 summonerLevel: int, summonerName: str, teamEarlySurrendered: bool, teamId: int, teamPosition: str,
+                 timeCCingOthers: int, timePlayed: int, totalDamageDealt: int, totalDamageDealtToChampions: int,
                  totalDamageShieldedOnTeammates: int, totalDamageTaken: int, totalHeal: int, totalHealsOnTeammates: int,
                  totalMinionsKilled: int, totalTimeCCDealt: int, totalTimeSpentDead: int, totalUnitsHealed: int,
                  tripleKills: int, trueDamageDealt: int, trueDamageDealtToChampions: int, trueDamageTaken: int,
-                 turretKills: int, turretsLost: int, unrealKills: int, visionScore: int,
-                 visionWardsBoughtInGame: int, wardsKilled: int, wardsPlaced: int, win: bool,
-                 inhibitorTakedowns: int = 0, nexusTakedowns: int = 0, turretTakedowns: int = 0, **kwargs):
+                 turretKills: int, unrealKills: int, visionScore: int, visionWardsBoughtInGame: int, wardsKilled: int,
+                 wardsPlaced: int, win: bool, inhibitorTakedowns: int = 0, nexusTakedowns: int = 0,
+                 turretTakedowns: int = 0, damageDealtToBuildings: int = 0, inhibitorsLost: int = 0, nexusLost: int = 0,
+                 turretsLost: int = 0, **kwargs):
         """
 
         :param assists:
@@ -1574,7 +1573,10 @@ class MTLFrameDto(RiotApiResponse):
         super().__init__(**kwargs)
         self.events: List[MTLEventDto] = list(map(lambda x: MTLEventDto(**x), events))
         self.participantFrames: List[MTLParticipantFrameDto] = list(
-            map(lambda x: MTLParticipantFrameDto(**x), participantFrames.values())
+            map(
+                lambda x: MTLParticipantFrameDto(**x),
+                map(lambda x: x[1], sorted(participantFrames.items(), key = lambda x: int(x[0])))
+            )
         )
         self.timestamp = timestamp
 
